@@ -97,4 +97,16 @@ type Integration struct {
 	RaindropToken                    string
 	RaindropCollectionID             string
 	RaindropTags                     string
+	NtfyEnabled                      bool
+	NtfyTopic                        string
+	NtfyURL                          string
+	NtfyAPIToken                     string
+	NtfyUsername                     string
+	NtfyPassword                     string
+	NtfyIconURL                      string
+	NtfyInternalLinks                bool
+	CuboxEnabled                     bool
+	CuboxAPILink                     string
+	DiscordEnabled                   bool
+	DiscordWebhookLink               string
 }
