@@ -200,7 +200,19 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 			raindrop_tags,
 			betula_enabled,
 			betula_url,
-			betula_token
+			betula_token,
+			ntfy_enabled,
+			ntfy_topic,
+			ntfy_url,
+			ntfy_api_token,
+			ntfy_username,
+			ntfy_password,
+			ntfy_icon_url,
+			ntfy_internal_links,
+			cubox_enabled,
+			cubox_api_link,
+			discord_enabled,
+			discord_webhook_link
 		FROM
 			integrations
 		WHERE
@@ -300,6 +312,18 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 		&integration.BetulaEnabled,
 		&integration.BetulaURL,
 		&integration.BetulaToken,
+		&integration.NtfyEnabled,
+		&integration.NtfyTopic,
+		&integration.NtfyURL,
+		&integration.NtfyAPIToken,
+		&integration.NtfyUsername,
+		&integration.NtfyPassword,
+		&integration.NtfyIconURL,
+		&integration.NtfyInternalLinks,
+		&integration.CuboxEnabled,
+		&integration.CuboxAPILink,
+		&integration.DiscordEnabled,
+		&integration.DiscordWebhookLink,
 	)
 	switch {
 	case err == sql.ErrNoRows:
@@ -407,9 +431,21 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 			raindrop_tags=$88,
 			betula_enabled=$89,
 			betula_url=$90,
-			betula_token=$91
+			betula_token=$91,
+			ntfy_enabled=$92,
+			ntfy_topic=$93,
+			ntfy_url=$94,
+			ntfy_api_token=$95,
+			ntfy_username=$96,
+			ntfy_password=$97,
+			ntfy_icon_url=$98,
+			ntfy_internal_links=$99,
+			cubox_enabled=$100,
+			cubox_api_link=$101,
+			discord_enabled=$102,
+			discord_webhook_link=$103
 		WHERE
-			user_id=$92
+			user_id=$104
 	`
 	_, err := s.db.Exec(
 		query,
@@ -504,6 +540,18 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 		integration.BetulaEnabled,
 		integration.BetulaURL,
 		integration.BetulaToken,
+		integration.NtfyEnabled,
+		integration.NtfyTopic,
+		integration.NtfyURL,
+		integration.NtfyAPIToken,
+		integration.NtfyUsername,
+		integration.NtfyPassword,
+		integration.NtfyIconURL,
+		integration.NtfyInternalLinks,
+		integration.CuboxEnabled,
+		integration.CuboxAPILink,
+		integration.DiscordEnabled,
+		integration.DiscordWebhookLink,
 		integration.UserID,
 	)
 
@@ -543,7 +591,9 @@ func (s *Storage) HasSaveEntry(userID int64) (result bool) {
 				webhook_enabled='t' OR
 				omnivore_enabled='t' OR
 				raindrop_enabled='t' OR
-				betula_enabled='t'
+				betula_enabled='t' OR
+				cubox_enabled='t' OR
+				discord_enabled='t'
 			)
 	`
 	if err := s.db.QueryRow(query, userID).Scan(&result); err != nil {
